@@ -988,15 +988,11 @@ class Base_Page(Borg, unittest.TestCase):
             self.exceptions.append("An exception occured when scrolling down")
             return None
 
-    def scroll_to_the_Bottom(self, locator, wait_time=0.5):
+    def key_press_END(self, locator, wait_time=0.5):
         "Scroll down"
         try:
             element = self.get_element(locator)
-            element.send_keys(Keys.PAGE_DOWN)
-            element.send_keys(Keys.PAGE_DOWN)
-            element.send_keys(Keys.PAGE_DOWN)
-            element.send_keys(Keys.PAGE_DOWN)
-            element.send_keys(Keys.PAGE_DOWN)
+            element.send_keys(Keys.END)
             self.wait(wait_time)
         except Exception as e:
             self.write(str(e), 'debug')
